@@ -84,7 +84,7 @@ def translate(img, model, max_seq_length=128, sos_token=1, eos_token=2):
             
 #            output = model(img, tgt_inp, tgt_key_padding_mask=None)
 #            output = model.transformer(src, tgt_inp, tgt_key_padding_mask=None)
-            output = model.transformer.forward_decoder(tgt_inp, memory)
+            output, memory = model.transformer.forward_decoder(tgt_inp, memory)
             output = output.to('cpu')
 
             values, indices  = torch.topk(output, 5)
@@ -108,7 +108,8 @@ def build_model(config):
     model = VietOCR(len(vocab),
             config['backbone'],
             config['cnn'], 
-            config['transformer'])
+            config['transformer'],
+            config['seq_modeling'])
     
     model = model.to(device)
 
